==> react-local-redux-1.0.0.tgz: package/es/connectLocal.js <==
// external dependencies
import { shallowEqual } from 'fast-equals';
import { Component, createElement } from 'react'; // constants

import { DEFAULT_OPTIONS } from './constants'; // utils

import { assign, composeMiddleware, getDisplayName, reduce } from './utils';
/**
 * @function createDispatch
 *
 * @description
 * create the dispatch method for the component
 *
 * @param {ReactComponent} instance the component instance
 * @param {function} reducer the reducer method
 * @returns {function(Object): void} the dispatch method for the component
 */

export var createDispatch = function createDispatch(instance, reducer) {
  var dispatch = function dispatch(action) {
    instance.__state = reducer(instance.__state, action);
    instance.setState(function () {
      return instance.__state;
    });
    return action;
  };

  var middlewareApi = {
    dispatch: dispatch,
    getState: instance.getState
  };
  return composeMiddleware(instance.options.middlewares.map(function (middleware) {
    return middleware(middlewareApi);
  }))(dispatch);
};
export var createGetState = function createGetState(instance) {
  return (
    /**
     * @function getState
     *
     * @description
     * get the current state of the component
     *
     * @returns {Object} the current state
     */
    function () {
      return instance.__state;
    }
  );
};
export var createShouldComponentUpdate = function createShouldComponentUpdate(instance) {
  return (
    /**
     * @function shouldComponentUpdate
     *
     * @description
     * determine whether the component should update based on the options provided
     *
     * @param {Object} nextProps the next props of the component
     * @param {Object} nextState the next reducer values
     * @param {Object} nextContext the next context of the component
     * @returns {boolean} should the component update
     */
    function (nextProps, nextState, nextContext) {
      var actionCreators = instance.actionCreators,
          context = instance.context,
          _instance$options = instance.options,
          areMergedPropsEqual = _instance$options.areMergedPropsEqual,
          areOwnPropsEqual = _instance$options.areOwnPropsEqual,
          areStatesEqual = _instance$options.areStatesEqual,
          mergeProps = _instance$options.mergeProps,
          pure = _instance$options.pure,
          props = instance.props,
          state = instance.state;

      if (!pure) {
        return true;
      }

      return !areOwnPropsEqual(props, nextProps) || !areStatesEqual(state, nextState) || !shallowEqual(context, nextContext) || !areMergedPropsEqual( // eslint workaround
      mergeProps(state, actionCreators, props), mergeProps(nextState, actionCreators, nextProps));
    }
  );
};
/**
 * @function getActionCreators
 *
 * @description
 * get the actionCreators wrapped with the dispatch method
 *
 * @param {Object} actionCreators the actionCreators to wrap
 * @param {function} dispatch the instance-specific dispatch function
 * @returns {Object} the wrapped actionCreators
 */

export var getActionCreators = function getActionCreators(actionCreators, dispatch) {
  return reduce(Object.keys(actionCreators), function (wrappedActionCreators, name) {
    wrappedActionCreators[name] = function () {
      return dispatch(actionCreators[name].apply(actionCreators, arguments));
    };

    return wrappedActionCreators;
  }, {});
};
/**
 * @function onConstruct
 *
 * @description
 * on construction of the instance, set the options and the instance-specific methods
 *
 * @param {ReactComponent} instance the component instance
 * @param {function} reducer the reducer with state
 * @param {Object} actionCreators the actionCreators to wrap with dispatch
 * @param {Object} options additional options for the component
 */

export var onConstruct = function onConstruct(instance, reducer, actionCreators, options) {
  // state
  instance.state = reducer(undefined, {});
  instance.__state = instance.state; // options

  instance.options = assign({}, DEFAULT_OPTIONS, options); // lifecycle methods

  instance.shouldComponentUpdate = createShouldComponentUpdate(instance); // instance methods

  instance.getState = createGetState(instance);
  instance.dispatch = createDispatch(instance, reducer); // instance values

  instance.actionCreators = actionCreators ? getActionCreators(actionCreators, instance.dispatch) : {
    dispatch: instance.dispatch
  };
};
/**
 * @function connectLocal
 *
 * @description
 * decorate a component with a higher-order component that manages local state
 * in the way that redux manages global state
 *
 * @param {function} reducer the reducer with state
 * @param {Object} actionCreators the actionCreators to wrap with dispatch
 * @param {Object} options additional options for the component
 * @returns {function}
 */

export var connectLocal = function connectLocal(reducer, actionCreators, options) {
  return (
    /**
     * @function ConnectedLocalComponent
     *
     * @description
     * higher-order component decorator which adds a redux-like manager for local state
     *
     * @param {ReactComponent} ComponentToConnect the component being wrapped
     * @returns {ReactComponent} the higher-order component
     */
    function (ComponentToConnect) {
      function ConnectedLocalComponent(initialProps) {
        Component.call(this, initialProps);
        onConstruct(this, reducer, actionCreators, options);

        this.render = function () {
          return createElement(ComponentToConnect, this.options.mergeProps(this.state, this.actionCreators, this.props));
        };

        return this;
      }

      ConnectedLocalComponent.prototype = Object.create(Component.prototype);
      ConnectedLocalComponent.displayName = "ConnectedLocal(" + getDisplayName(ComponentToConnect) + ")";
      return ConnectedLocalComponent;
    }
  );
};

==> react-local-redux-2.0.0.tgz: package/es/connectLocal.js <==
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

// external dependencies
import { shallowEqual } from 'fast-equals';
import { Component, createElement } from 'react';
import { applyMiddleware, createStore } from 'redux'; // constants

import { DEFAULT_OPTIONS } from './constants'; // utils

import { assign, getDisplayName, identity, reduce } from './utils';
export var createGetState = function createGetState(instance) {
  return (
    /**
     * @function getState
     *
     * @description
     * get the current state of the component
     *
     * @returns {Object} the current state
     */
    function () {
      return instance.__state;
    }
  );
};
export var createShouldComponentUpdate = function createShouldComponentUpdate(instance) {
  return (
    /**
     * @function shouldComponentUpdate
     *
     * @description
     * determine whether the component should update based on the options provided
     *
     * @param {Object} nextProps the next props of the component
     * @param {Object} nextState the next reducer values
     * @param {Object} nextContext the next context of the component
     * @returns {boolean} should the component update
     */
    function (nextProps, nextState, nextContext) {
      var actionCreators = instance.actionCreators,
          context = instance.context,
          _instance$options = instance.options,
          areMergedPropsEqual = _instance$options.areMergedPropsEqual,
          areOwnPropsEqual = _instance$options.areOwnPropsEqual,
          areStatesEqual = _instance$options.areStatesEqual,
          mergeProps = _instance$options.mergeProps,
          pure = _instance$options.pure,
          props = instance.props,
          state = instance.state;

      if (!pure) {
        return true;
      }

      return !areOwnPropsEqual(props, nextProps) || !areStatesEqual(state, nextState) || !shallowEqual(context, nextContext) || !areMergedPropsEqual( // eslint workaround
      mergeProps(state, actionCreators, props), mergeProps(nextState, actionCreators, nextProps));
    }
  );
};
export var createComponentWillUnmount = function createComponentWillUnmount(instance) {
  return (
    /**
     * @function componentWillMount
     *
     * @description
     * on unmount, unsubscribe from the store and remove it
     */
    function () {
      instance.__unsubscribe();

      instance.__store = null;
    }
  );
};
/**
 * @function getActionCreators
 *
 * @description
 * get the actionCreators wrapped with the dispatch method
 *
 * @param {Object} actionCreators the actionCreators to wrap
 * @param {function} dispatch the instance-specific dispatch function
 * @returns {Object} the wrapped actionCreators
 */

export var getActionCreators = function getActionCreators(actionCreators, dispatch) {
  return reduce(Object.keys(actionCreators), function (wrappedActionCreators, name) {
    wrappedActionCreators[name] = function () {
      return dispatch(actionCreators[name].apply(actionCreators, arguments));
    };

    return wrappedActionCreators;
  }, {});
};
/**
 * @function onConstruct
 *
 * @description
 * on construction of the instance, set the options and the instance-specific methods
 *
 * @param {ReactComponent} instance the component instance
 * @param {function} reducer the reducer with state
 * @param {Object} actionCreators the actionCreators to wrap with dispatch
 * @param {function} [enhancer=identity] the method to create the store enhancer
 * @param {Array<function>} [middlewares=[]] the list of middlewares to apply
 * @param {Object} options additional options for the component
 */

export var onConstruct = function onConstruct(instance, reducer, actionCreators, _temp) {
  var _ref = _temp === void 0 ? {} : _temp,
      _ref$enhancer = _ref.enhancer,
      enhancer = _ref$enhancer === void 0 ? identity : _ref$enhancer,
      _ref$middlewares = _ref.middlewares,
      middlewares = _ref$middlewares === void 0 ? [] : _ref$middlewares,
      options = _objectWithoutPropertiesLoose(_ref, ["enhancer", "middlewares"]);

  // options
  instance.options = assign({}, DEFAULT_OPTIONS, options); // store

  instance.__store = createStore(reducer, enhancer(applyMiddleware.apply(void 0, middlewares)));
  instance.__unsubscribe = instance.__store.subscribe(function () {
    return instance.setState(function () {
      return instance.__store.getState();
    });
  }); // lifecycle methods

  instance.shouldComponentUpdate = createShouldComponentUpdate(instance);
  instance.componentWillUnmount = createComponentWillUnmount(instance); // instance methods

  instance.getState = createGetState(instance); // instance values

  instance.actionCreators = actionCreators ? getActionCreators(actionCreators, instance.__store.dispatch) : {
    dispatch: instance.__store.dispatch
  };
  instance.state = instance.__store.getState();
};
/**
 * @function connectLocal
 *
 * @description
 * decorate a component with a higher-order component that manages local state
 * in the way that redux manages global state
 *
 * @param {function} reducer the reducer with state
 * @param {Object} actionCreators the actionCreators to wrap with dispatch
 * @param {Object} options additional options for the component
 * @returns {function}
 */

export var connectLocal = function connectLocal(reducer, actionCreators, options) {
  return (
    /**
     * @function ConnectedLocalComponent
     *
     * @description
     * higher-order component decorator which adds a redux-like manager for local state
     *
     * @param {ReactComponent} ComponentToConnect the component being wrapped
     * @returns {ReactComponent} the higher-order component
     */
    function (ComponentToConnect) {
      function ConnectedLocalComponent(initialProps) {
        Component.call(this, initialProps);
        onConstruct(this, reducer, actionCreators, options);

        this.render = function () {
          return createElement(ComponentToConnect, this.options.mergeProps(this.state, this.actionCreators, this.props));
        };

        return this;
      }

      ConnectedLocalComponent.prototype = Object.create(Component.prototype);
      ConnectedLocalComponent.displayName = "ConnectedLocal(" + getDisplayName(ComponentToConnect) + ")";
      return ConnectedLocalComponent;
    }
  );
};
